@@ -38,9 +38,9 @@ module Nokogiri
             options = cfg
             options.nonet.nowarning.dtdattr
           end
-          assert(options.nonet?)
-          assert(options.nowarning?)
-          assert(options.dtdattr?)
+          assert_predicate(options, :nonet?)
+          assert_predicate(options, :nowarning?)
+          assert_predicate(options, :dtdattr?)
         end
 
         def test_parse_takes_config_block
@@ -49,9 +49,9 @@ module Nokogiri
             options = cfg
             options.nonet.nowarning.dtdattr
           end
-          assert(options.nonet?)
-          assert(options.nowarning?)
-          assert(options.dtdattr?)
+          assert_predicate(options, :nonet?)
+          assert_predicate(options, :nowarning?)
+          assert_predicate(options, :dtdattr?)
         end
 
         def test_subclass
@@ -339,7 +339,7 @@ module Nokogiri
 
         def test_HTML_function
           html = Nokogiri::HTML(File.read(HTML_FILE))
-          assert(html.html?)
+          assert_predicate(html, :html?)
         end
 
         def test_parse_works_with_an_object_that_responds_to_read
@@ -535,9 +535,9 @@ module Nokogiri
         def test_dup_document
           assert(dup = html.dup)
           refute_equal(dup, html)
-          assert(html.html?)
+          assert_predicate(html, :html?)
           assert_instance_of(Nokogiri::HTML::Document, dup)
-          assert(dup.html?, "duplicate should be html")
+          assert_predicate(dup, :html?, "duplicate should be html")
           assert_equal(html.to_s, dup.to_s)
         end
 
@@ -641,7 +641,7 @@ module Nokogiri
           File.open(HTML_FILE, "rb") do |f|
             html = Nokogiri::HTML(f)
           end
-          assert(html.html?)
+          assert_predicate(html, :html?)
           assert_equal(HTML_FILE, html.url)
         end
 
@@ -668,8 +668,8 @@ module Nokogiri
         end
 
         def test_html?
-          refute(html.xml?)
-          assert(html.html?)
+          refute_predicate(html, :xml?)
+          assert_predicate(html, :html?)
         end
 
         def test_serialize
@@ -727,6 +727,17 @@ module Nokogiri
           assert_equal(0, doc.errors.length)
         end
 
+        def test_leaking_dtd_nodes_after_internal_subset_removal
+          # see https://github.com/sparklemotion/nokogiri/issues/1784
+          #
+          # just checking that this doesn't raise a valgrind error. we
+          # don't otherwise have any test coverage for removing DTDs.
+          #
+          100.times do |_i|
+            Nokogiri::HTML::Document.new.internal_subset.remove
+          end
+        end
+
         it "skips encoding for script tags" do
           html = Nokogiri::HTML(<<~EOHTML)
             <html>
@@ -763,15 +774,17 @@ module Nokogiri
           assert_equal "ISO-8859-1", html.encoding.name
         end
 
-        def test_leaking_dtd_nodes_after_internal_subset_removal
-          # see https://github.com/sparklemotion/nokogiri/issues/1784
-          #
-          # just checking that this doesn't raise a valgrind error. we
-          # don't otherwise have any test coverage for removing DTDs.
-          #
-          100.times do |_i|
-            Nokogiri::HTML::Document.new.internal_subset.remove
+        it "handles ill-formed processing instructions" do
+          html = %{<html><body><!--><?a/}
+          doc = Nokogiri::HTML4::Document.parse(html)
+          expected = if Nokogiri.jruby?
+            [Nokogiri::XML::Node::COMMENT_NODE, Nokogiri::XML::Node::PI_NODE]
+          elsif Nokogiri.libxml2_patches.include?("0008-htmlParseComment-handle-abruptly-closed-comments.patch")
+            [Nokogiri::XML::Node::COMMENT_NODE]
+          else
+            []
           end
+          assert_equal(expected, doc.at_css("body").children.map(&:type))
         end
 
         describe ".parse" do
@@ -780,7 +793,34 @@ module Nokogiri
           end
 
           it "sets the test up correctly" do
-            assert(html_strict.strict?)
+            assert_predicate(html_strict, :strict?)
+          end
+
+          describe "ill-formed < character" do
+            let(:input) { %{<html><body><div>this < that</div><div>second element</div></body></html>} }
+
+            it "skips to the next start tag" do
+              # see https://github.com/sparklemotion/nokogiri/issues/2461 for why we're testing this edge case
+              doc = Nokogiri::HTML4.parse(input)
+              body = doc.at_xpath("//body")
+
+              if Nokogiri.uses_libxml?("= 2.9.13")
+                # <body><div>this <div>second element</div></div></body>
+                assert_equal(1, body.children.length)
+                body.children.first.tap do |div|
+                  assert_equal(2, div.children.length)
+                  assert_equal("this ", div.children[0].content)
+                  assert_equal("div", div.children[1].name)
+                  assert_equal("second element", div.children[1].content)
+                end
+              else
+                # <body><div>this &lt; that</div><div>second element</div></body>
+                assert_equal(2, body.children.length)
+                assert_equal(["div", "div"], body.children.map(&:name), body.to_html)
+                assert_equal("this < that", body.children[0].text, body.to_html)
+                assert_equal("second element", body.children[1].text, body.to_html)
+              end
+            end
           end
 
           describe "read memory" do
